Name:           python-absl-py
Version:        0.13.0
Release:        2%{?dist}
Summary:        Abseil Python Common Libraries

# Overall license is ASL 2.0. Contents of absl/third_party/unittest3_backport/
# are under the Python license (derived from the Python 3 standard library).
License:        ASL 2.0 and Python
URL:            https://github.com/abseil/abseil-py/
Source0:        %{url}/archive/pypi-v%{version}/abseil-py-pypi-v%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  python%{python3_pkgversion}-devel >= 3.4
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-six

BuildRequires:  python2-devel >= 2.7
BuildRequires:  python2-setuptools
BuildRequires:  python2-six
BuildRequires:  python2-enum34

%global common_description %{expand:
This repository is a collection of Python library code for building Python
applications. The code is collected from Google’s own Python code base, and has
been extensively tested and used in production.

Features:

  • Simple application startup
  • Distributed commandline flags system
  • Custom logging module with additional features
  • Testing utilities}

%description %{common_description}


%package -n     python%{python3_pkgversion}-absl-py
Summary:        %{summary}
%{?python_provide:%python_provide python%{python3_pkgversion}-absl-py}

Requires:       python%{python3_pkgversion}-six

%description -n python%{python3_pkgversion}-absl-py %{common_description}


%package -n     python2-absl-py
Summary:        %{summary}
%{?python_provide:%python_provide python2-absl-py}

Requires:       python2-six
Requires:       python2-enum34

%description -n python2-absl-py %{common_description}


%prep
%autosetup -n abseil-py-pypi-v%{version}
cp -p absl/third_party/unittest3_backport/LICENSE LICENSE-PYTHON

# Despite the third_party/ prefix, absl/third_party/unittest3_backport/ is not
# exactly a bundled library. On Python 3, it is merely a shim around the
# unittest module from the Python standard library. On Python 2, it is a
# backport of much of the added functionality from the Python 3 version of the
# unittest module; while derived from some version of the Python 3 standard
# library, this backport is specific to absl-py, is maintained in the same
# source code repository, and appears not to be separately distributed or used
# by any other software.


%build
%py3_build
%py2_build


%install
%py3_install
# No async support in Python 2; if we built with bazel (not available in EPEL),
# it would take care of not installing this in the Python 2 environment. We
# need to remove it manually instead. If we left it, byte-compiling would fail
# with a syntax error.
find . -name _parameterized_async.py -print -delete
%py2_install


%check
# We cannot use smoke_tests/smoke_test.sh because it downloads things from the
# Internet. We can, however, run the sample Python scripts manually, which is
# better than nothing.
PYTHONPATH=%{buildroot}/%{python3_sitelib}; export PYTHONPATH
%{__python3} smoke_tests/sample_app.py --echo smoke
%{__python3} smoke_tests/sample_test.py
PYTHONPATH=%{buildroot}/%{python2_sitelib}; export PYTHONPATH
%{__python2} smoke_tests/sample_app.py --echo smoke
%{__python2} smoke_tests/sample_test.py

# Running the actual test suite requires bazel, which will almost certainly
# never be packaged for EPEL due to its Byzantine mass of bundled
# dependencies. It is possible to invoke the tests with another runner, such as
# pytest, but there are many spurious failures due to the incorrect
# environment, so it is useless to do so.


%files -n python%{python3_pkgversion}-absl-py
%license LICENSE
%license LICENSE-PYTHON
%doc AUTHORS
%doc absl/CHANGELOG.md
%doc CONTRIBUTING.md
%doc README.md
%doc smoke_tests

%{python3_sitelib}/absl
%{python3_sitelib}/absl_py-%{version}-py%{python3_version}.egg-info

%files -n python2-absl-py
%license LICENSE
%license LICENSE-PYTHON
%doc AUTHORS
%doc CONTRIBUTING.md
%doc README.md
%doc smoke_tests

%{python2_sitelib}/absl
%{python2_sitelib}/absl_py-%{version}-py%{python2_version}.egg-info


%changelog
* Fri Sep 17 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.13.0-2
- Switch from py_provides to older python_provide
- Reduce macro indirection in the spec file

* Tue Jun 15 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.13.0-1
- Update to 0.13.0; closes RHBZ#1972146

* Wed Mar 10 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.12.0-2
- Add CHANGELOG.md, from absl/, to documentation

* Wed Mar 10 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.12.0-1
- Update to 0.12.0
- Drop python-absl-py-0.11.0-python-3.10.patch, now upstreamed

* Wed Mar 10 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.11.0-3
- Move BR’s back to top-level package
- Fix bogus changelog versions

* Thu Nov 26 2020 Benjamin A. Beasley <code@musicinmybrain.net> - 0.11.0-2
- Remove EPEL conditionals from Fedora spec file

* Wed Nov 25 2020 Benjamin A. Beasley <code@musicinmybrain.net> - 0.11.0-1
- Initial package
